Examples ▲ Prism

# Different markup

## code.language-css

`p { color: red; }`

## pre.language-css > code

    p { color: red; }

## pre > code.language-css

    p { color: red; }

## pre.language-css > code.language-*

    p { color: red; }

## code.lang-css

`p { color: red; }`

## pre.lang-css > code

    p { color: red; }

## pre > code

No language, should inherit .language-markup

    <p>hi!</p>

## code.language-*

No language, should inherit .language-markup

`<p>hi!</p>`

## code.language-none

Should not be highlighted.

`<p>hi!</p>`

# Per language examples